package
Version:
v0.2.7
Opens a new window with list of versions in this module.
Published: Aug 5, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Spell struct {
Name string `json:"name"`
FadeMessage string `json:"fade_message"`
Classes []string `json:"classes"`
IconID int `json:"icon_id"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.